# coding: utf-8
# Copyright (c) Pymatgen Development Team.
# Distributed under the terms of the MIT License.

"""
Package for analysis of magnetic structures.
"""

from pymatgen.analysis.magnetism.analyzer import *  # noqa
